==> libkdepim-17.07.80.tar.xz: libkdepim-17.07.80/src/libkdepimakonadi/addressline/plugins/addressesslineeditpluginmanager.h <==
/*
   Copyright (C) 2017 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ADDRESSESSLINEEDITPLUGINMANAGER_H
#define ADDRESSESSLINEEDITPLUGINMANAGER_H

#include <QObject>
#include "kdepim_export.h"

namespace KPIM {
class AddressessLineEditAbstractPlugin;
class AddressessLineEditPluginManagerPrivate;
class KDEPIM_EXPORT AddressessLineEditPluginManager : public QObject
{
    Q_OBJECT
public:
    explicit AddressessLineEditPluginManager(QObject *parent = nullptr);
    ~AddressessLineEditPluginManager();

    static AddressessLineEditPluginManager *self();

    KPIM::AddressessLineEditAbstractPlugin *plugin(const QString &identifier);
    QVector<KPIM::AddressessLineEditAbstractPlugin *> pluginsList() const;

private:
    AddressessLineEditPluginManagerPrivate *const d;
};
}

#endif // ADDRESSESSLINEEDITPLUGINMANAGER_H

==> libkdepim-18.11.90.tar.xz: libkdepim-18.11.90/src/libkdepimakonadi/addressline/plugins/addressesslineeditpluginmanager.h <==
/*
   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ADDRESSESSLINEEDITPLUGINMANAGER_H
#define ADDRESSESSLINEEDITPLUGINMANAGER_H

#include <QObject>
#include "kdepimakonadi_export.h"

namespace KPIM {
class AddressessLineEditAbstractPlugin;
class AddressessLineEditPluginManagerPrivate;
class KDEPIMAKONADI_EXPORT AddressessLineEditPluginManager : public QObject
{
    Q_OBJECT
public:
    explicit AddressessLineEditPluginManager(QObject *parent = nullptr);
    ~AddressessLineEditPluginManager();

    static AddressessLineEditPluginManager *self();

    KPIM::AddressessLineEditAbstractPlugin *plugin(const QString &identifier);
    QVector<KPIM::AddressessLineEditAbstractPlugin *> pluginsList() const;

private:
    AddressessLineEditPluginManagerPrivate *const d;
};
}

#endif // ADDRESSESSLINEEDITPLUGINMANAGER_H
